#include <stdlib.h>
#include <stdio.h>


extern int errno;

#include <unistd.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/stat.h>

#include <fcntl.h>
#include <termios.h>
#include <signal.h>

#include <string.h>

#include "ft100.h"


/*
 * 
 * this is the main command to set stuff
 *
 */

int main(int argc, char* argv[]) 
{
   FT100_CMD     ft100_cmd;
   FT100_STATUS  ft100_status;
   FT100_METER   ft100_meter;
   char          device[100];
   
   struct termios termattribs;
   struct termios *defaults_serial;
   
   int fdSer; 
   int i,j;
   
   
   /*
    * 
    * Process cmdline parms
    * 
    */
    
    /*
     *               command line switches used
     * 
     * -m set operating mode
     * -f set frequency
     * -c set ctcss/pl tone
     * -g get status
     * -d set dcs tone
     * -v set active vfo
     * -s set split on/off 
     * -t set ctcss/dcs mode 
     * -r set repeater shift 
     * -p set ptt
     * -l set filter
     *
     * -D set device name
     * -V get program version
     */ 
    // printf("#Args   =  %i\n",argc);
    /*
     * 
     * see if we got a device name, otherwise use /dev/ft100
     * 
     */
    strcpy(device,"/dev/ft100");
    for (i=1; i<argc; i+=2)
	if (strcmp(argv[i],"-D") == 0)
	    strcpy(device,argv[i+1]);
    printf("Using device=%s\n",device);
   
      /*
    * 
    * /dev/ft100 is a symlink to the actual /devttySx
    * device that the radio is attached to. Eventually
    * this should be moved out to the command line or 
    * a config file
    *
    * 
    * so open the device and then set up the io parms
    * for it
    * 
    * 
    */
   
  
   fdSer = open(device, O_RDWR | O_NOCTTY | O_NDELAY | O_NONBLOCK);
   if (fdSer < 0) 
      {  
	  printf("Open of %s failed \n",device);
	  exit(3);
      }
      
       
   termattribs.c_iflag = IGNBRK | IGNPAR | IMAXBEL | IXOFF;
   termattribs.c_oflag = 0;
   termattribs.c_cflag = CS8 | CSTOPB | CREAD | CLOCAL | CRTSCTS;
   termattribs.c_lflag = 0;
   termattribs.c_cc[VMIN] = 1;
   termattribs.c_cc[VTIME] = 0;
   cfsetispeed(&termattribs,B4800);
   cfsetospeed(&termattribs,B4800);      
   tcsetattr(fdSer,TCSANOW,&termattribs);

		   
    for (i=1; i<argc; i+=2)
      {
         // printf("arg #%i   = %s       parm = %s\n", i, argv[i], argv[i+1]);
         
	 // show version
	 if (strcmp(argv[i], "-V")==0)
	   {
	      printf(VERSION);
	      i--;
	   }
	 
	 
	 // set mode
	 if (strcmp(argv[i], "-m")==0)
	    if(ft100_set_mode(fdSer, argv[i+1])!=0)
	       {
		  printf("Mode set Failed\n");
		  exit(3);
	       }
	 
	 // set freq
	 if (strcmp(argv[i], "-f")==0)
	    if(ft100_set_freq(fdSer, argv[i+1])!=0)
	     {
		printf("Freq set failed\n");
		exit(3);
	     }
         
	 
	 // set ctcss
	 if (strcmp(argv[i], "-c")==0)
	    if(ft100_set_ctcss(fdSer, argv[i+1])!=0)
	     {
		printf("CTCSS set failed\n");
		exit(3);
	     }
	 
	 // set dcs
	 if (strcmp(argv[i], "-d")==0)
	    if(ft100_set_dcs(fdSer, argv[i+1])!=0)
	     {
		printf("DCS set failed\n");
		exit(3);
	     }
	 
	 // get status
	 if (strcmp(argv[i], "-g")==0)
	   {
	     ft100_read_status(device, fdSer,&ft100_status);
	     ft100_show_status(ft100_status); 
             ft100_read_meter(device, fdSer,&ft100_meter);
	     ft100_show_meter(ft100_meter); 
             i--; 
	   }
	 
	 // set vfo
	 if (strcmp(argv[i], "-v")==0)
	    if(ft100_set_vfo(fdSer, argv[i+1])!=0)
	     {
		printf("VFO set failed\n");
		exit(3);
	     }
	 
	 // set split
	 if (strcmp(argv[i], "-s")==0)
	    if(ft100_set_split(fdSer, argv[i+1])!=0)
	     {
		printf("SPLIT set failed\n");
		exit(3);
	     }

         // set dcs/ctcss mode
	 if (strcmp(argv[i], "-t")==0)
            if(ft100_set_dcs_ctcss_mode(fdSer, argv[i+1])!=0)
              {
		 printf("DCS/CTCSS mode failed\n");
		 exit(3);	      
	      }
	 // set repeater shift
	 if (strcmp(argv[i], "-r")==0)
	   if(ft100_set_repeater_shift(fdSer, argv[i+1])!=0)
	     {
		printf("Repeater shift failed\n");
		exit(3);
	     }

	 // set ptt
	 if (strcmp(argv[i], "-p")==0)
	   if(ft100_set_ptt(fdSer, argv[i+1])!=0)
	     {
		printf("PTT set failed\n");
		exit(3);
	     }

	 // set filter
	 if (strcmp(argv[i], "-l")==0)
	   if(ft100_set_filter(fdSer, argv[i+1])!=0)
	     {
		printf("filter set failed\n");
		exit(3);
	     }
	 
      }
   
   close(fdSer);
   return;
}
  
